
## CATO-CLI - query.site.availableVersionList:
[Click here](https://api.catonetworks.com/documentation/#query-availableVersionList) for documentation on this operation.

### Usage for query.site.availableVersionList:

`catocli query site availableVersionList -h`

`catocli query site availableVersionList <json>`

`catocli query site availableVersionList "$(cat < availableVersionList.json)"`

`catocli query site availableVersionList '{"availableVersionListInput": {"platforms": {"platforms": ["String"]}}}'`

#### Operation Arguments for query.site.availableVersionList ####
`accountId` [ID] - (required) N/A 
`availableVersionListInput` [AvailableVersionListInput] - (required) N/A 
